DOM API
=======

(This section is not complete and not enough yet...)

``wdom.dom.Tag`` class provides DOM implementation which is synchronized on
python and browser.


.. automodule:: wdom.tag

   .. autoclass:: Tag
      :members:
      :inherited-members:
      :undoc-members:

   .. autofunction:: NewTagClass

   .. autoclass:: TagBaseMeta
      :members:
      :undoc-members:
